==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/bean/BannerAdBean.java <==
package com.yifan.yf_ads.bean;

import org.json.JSONException;
import org.json.JSONObject;

public class BannerAdBean {
    int width;
    int height;
    boolean showDislike;
    String positionId;
    int adSizeIndex;
    int cornerSize;
    int uniqueKey;


    public static BannerAdBean parseObject(String jsonString) throws JSONException {
        BannerAdBean bean = new BannerAdBean();
        JSONObject jsonObject = new JSONObject(jsonString);
        bean.positionId = jsonObject.optString("positionId");
        bean.width = jsonObject.optInt("width");
        bean.height = jsonObject.optInt("height");
        bean.showDislike = jsonObject.optBoolean("showDislike");
        bean.adSizeIndex = jsonObject.optInt("adSizeIndex");
        bean.cornerSize = jsonObject.optInt("cornerSize");
        bean.uniqueKey = jsonObject.optInt("uniqueKey");
        return bean;
    }


    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public boolean isShowDislike() {
        return showDislike;
    }

    public void setShowDislike(boolean showDislike) {
        this.showDislike = showDislike;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public int getAdSizeIndex() {
        return adSizeIndex;
    }

    public void setAdSizeIndex(int adSizeIndex) {
        this.adSizeIndex = adSizeIndex;
    }

    public int getCornerSize() {
        return cornerSize;
    }

    public void setCornerSize(int cornerSize) {
        this.cornerSize = cornerSize;
    }

    public int getUniqueKey() {
        return uniqueKey;
    }

    public void setUniqueKey(int uniqueKey) {
        this.uniqueKey = uniqueKey;
    }
}

==> 0.0.8.tar.gz: android/src/main/java/com/yifan/yf_ads/bean/BannerAdBean.java <==
package com.yifan.yf_ads.bean;

import org.json.JSONException;
import org.json.JSONObject;

public class BannerAdBean {
    int width;
    int height;
    boolean showDislike;
    String positionId;
    int adSizeIndex;
    int cornerSize;
    String uniqueKey;
    boolean isAutoShow;


    public static BannerAdBean parseObject(String jsonString) throws JSONException {
        BannerAdBean bean = new BannerAdBean();
        JSONObject jsonObject = new JSONObject(jsonString);
        bean.positionId = jsonObject.optString("positionId");
        bean.width = jsonObject.optInt("width");
        bean.height = jsonObject.optInt("height");
        bean.showDislike = jsonObject.optBoolean("showDislike");
        bean.adSizeIndex = jsonObject.optInt("adSizeIndex");
        bean.cornerSize = jsonObject.optInt("cornerSize");
        bean.uniqueKey = jsonObject.optString("uniqueKey");
        bean.isAutoShow = jsonObject.optBoolean("loadAndShow");
        return bean;
    }


    public int getWidth() {
        return width;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getHeight() {
        return height;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public boolean isShowDislike() {
        return showDislike;
    }

    public void setShowDislike(boolean showDislike) {
        this.showDislike = showDislike;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public int getAdSizeIndex() {
        return adSizeIndex;
    }

    public void setAdSizeIndex(int adSizeIndex) {
        this.adSizeIndex = adSizeIndex;
    }

    public int getCornerSize() {
        return cornerSize;
    }

    public void setCornerSize(int cornerSize) {
        this.cornerSize = cornerSize;
    }

    public String getUniqueKey() {
        return uniqueKey;
    }

    public void setUniqueKey(String uniqueKey) {
        this.uniqueKey = uniqueKey;
    }

    public boolean isAutoShow() {
        return isAutoShow;
    }

    public void setAutoShow(boolean autoShow) {
        isAutoShow = autoShow;
    }
}
